==> viha-5.15.tar.gz: viha-5.15/paikka.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paikka";
$file = basename(__FILE__);

include "common.php";
include "paikka-ok.php";

echo "
<html>
<head>
 <title>VIHA - Sijaintikoodit (paikat)</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi(). ", sijaintikoodien ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$paikka = get_txt('paikka');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu("$file", $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = paikka_add_ok($herja,s('alue'),
		       s('paivystys'),$paikka);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
              SET alue_id = " . s("alue") . ",
                  paivystys_id = " . s("paivystys") . ",
                  paikka = '$paikka',
                  ts = '$now'";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = paikka_save_ok($herja,$id,s('alue'),
			s('paivystys'),
			$paikka);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id=" . s("paivystys") . ",
           paikka='$paikka',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = paikka_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $paikka = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = paikka_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $paikka = $a['paikka'];
}		  

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Sijaintikoodi:";
if ($readonly) {
  echo "<td>$paikka\n";
} else {
  echo "<td><input type=\"text\" name=\"paikka\" size=64 maxlength=64";
  echo " value=\"$paikka\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result = my_mysql_query("
SELECT *
FROM $table
ORDER BY paikka
");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Sijaintikoodi\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]", "<TD>$a[ts]", "<TD>$a[paikka]";
    if (($id == "0") && ($a['id'] > 3)) {
      echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei sijaintikoodeja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paikka.php,v 1.13 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/paikka.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paikka";
$file = basename(__FILE__);

include "common.php";
include "paikka-ok.php";

echo "
<html>
<head>
 <title>VIHA - Sijaintikoodit (paikat)</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio(). ", sijaintikoodien ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$paikka = get_txt('paikka');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu("$file", $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = paikka_add_ok($herja,s('alue'),
		       s('paivystys'),$paikka);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
              SET alue_id = " . s("alue") . ",
                  paivystys_id = " . s("paivystys") . ",
                  paikka = '$paikka',
                  ts = '$now'";
    $result = my_mysql_query ($sql);
    loki("$sql id=" . last_insert_id());
    $msg = "Listty sijaintikoodi $paikka";
    taktinen_loki($msg);
    tehty($msg);
    $clear = "ADD";
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = paikka_save_ok($herja,$id,s('alue'),
			s('paivystys'),
			$paikka);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id=" . s("paivystys") . ",
           paikka='$paikka',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = "Pivitetty sijaintikoodia $paikka";
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = paikka_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $msg = "Poistettu sijaintikoodi " . ota_paikka($id);
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql,true,true);
    $clear = "SISINEN";
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $paikka = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = paikka_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $paikka = $a['paikka'];
}		  

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Sijaintikoodi:";
if ($readonly) {
  echo "<td>$paikka\n";
} else {
  echo "<td><input type=\"text\" name=\"paikka\" size=64 maxlength=64";
  echo " value=\"$paikka\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result = my_mysql_query("
SELECT *
FROM $table
ORDER BY paikka
");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Sijaintikoodi\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]", "<TD>$a[ts]", "<TD>$a[paikka]";
    if (($id == "0") && ($a['id'] > 4)) {
      echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei sijaintikoodeja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paikka.php,v 1.17 2009/10/06 08:20:04 riku Exp $ -->
